==> apache-eventmesh-1.9.0-source.tar.gz: apache-eventmesh-1.9.0-src/eventmesh-security-plugin/eventmesh-security-acl/src/test/java/org/apache/eventmesh/acl/impl/AclServiceImplTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.eventmesh.acl.impl;

import org.apache.eventmesh.api.acl.AclProperties;
import org.apache.eventmesh.api.acl.AclService;
import org.apache.eventmesh.api.exception.AclException;


import org.junit.Assert;
import org.junit.BeforeClass;
import org.junit.Test;

public class AclServiceImplTest {

    private static AclService service;

    @BeforeClass
    public static void beforeClass() {
        service = new AclServiceImpl();
    }

    @Test
    public void testInit() {
        try {
            service.init();
        } catch (AclException e) {
            Assert.fail(e.getMessage());
        }
    }

    @Test
    public void testStart() {
        try {
            service.start();
        } catch (AclException e) {
            Assert.fail(e.getMessage());
        }
    }

    @Test
    public void testShutdown() {
        try {
            service.shutdown();
        } catch (AclException e) {
            Assert.fail(e.getMessage());
        }
    }

    @Test
    public void testDoAclCheckInConnect() {
        try {
            service.doAclCheckInConnect(new AclProperties());
        } catch (AclException e) {
            Assert.fail(e.getMessage());
        }
    }

    @Test
    public void testDoAclCheckInHeartbeat() {
        try {
            service.doAclCheckInHeartbeat(new AclProperties());
        } catch (AclException e) {
            Assert.fail(e.getMessage());
        }
    }

    @Test
    public void testDoAclCheckInSend() {
        try {
            service.doAclCheckInSend(new AclProperties());
        } catch (AclException e) {
            Assert.fail(e.getMessage());
        }
    }

    @Test
    public void testDoAclCheckInReceive() {
        try {
            service.doAclCheckInReceive(new AclProperties());
        } catch (AclException e) {
            Assert.fail(e.getMessage());
        }
    }
}

==> apache-eventmesh-1.12.0-source.tar.gz: apache-eventmesh-1.12.0-src/eventmesh-security-plugin/eventmesh-security-acl/src/test/java/org/apache/eventmesh/acl/impl/AclServiceImplTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.eventmesh.acl.impl;

import org.apache.eventmesh.api.acl.AclProperties;
import org.apache.eventmesh.api.acl.AclService;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.BeforeAll;
import org.junit.jupiter.api.Test;

public class AclServiceImplTest {

    private static AclService service;

    @BeforeAll
    public static void beforeClass() {
        service = new AclServiceImpl();
    }

    @Test
    public void testInit() {
        Assertions.assertDoesNotThrow(service::init);
    }

    @Test
    public void testStart() {
        Assertions.assertDoesNotThrow(service::start);
    }

    @Test
    public void testShutdown() {
        Assertions.assertDoesNotThrow(service::shutdown);
    }

    @Test
    public void testDoAclCheckInConnect() {
        Assertions.assertDoesNotThrow(() -> service.doAclCheckInConnect(new AclProperties()));
    }

    @Test
    public void testDoAclCheckInHeartbeat() {
        Assertions.assertDoesNotThrow(() -> service.doAclCheckInHeartbeat(new AclProperties()));
    }

    @Test
    public void testDoAclCheckInSend() {
        Assertions.assertDoesNotThrow(() -> service.doAclCheckInSend(new AclProperties()));
    }

    @Test
    public void testDoAclCheckInReceive() {
        Assertions.assertDoesNotThrow(() -> service.doAclCheckInReceive(new AclProperties()));
    }
}
